﻿'use strict';

// Google Analytics Collection APIs Reference:
// https://developers.google.com/analytics/devguides/collection/analyticsjs/

var baseUrl = 'http://localhost/AssetMan';

angular.module('app.controllers', [])

    // Path: /computers
    .controller('ComputersCtrl', ['$scope', '$location', '$window', '$http', function ($scope, $location, $window, $http) {
        $scope.$root.title = 'AssetMan | Computers';
        $scope.title = "Manually added computers";
        $scope.computerform = {};

        $scope.computerform.create_timestamp = new Date();
        $scope.computerform.modify_timestamp = new Date();

        $scope.getComputers = function () {
            $http({
                method: 'GET',
                url: baseUrl + '/api/ManualComputers'
            }).
            success(function (data, status, headers, config) {
                $scope.computers = data;
            }).
            error(function (data, status, headers, config) {
                $scope.status = status;
            });
        }

        $scope.addComputer = function () {
            $http({
                method: 'POST',
                url: baseUrl + '/api/ManualComputers',
                headers: { 'Content-Type': 'application/json' },
                data: $scope.computerform
            }).success(function (data) {
                console.log(data);
                $scope.computers.push(data);
                $scope.message = data.machine_name + ' added successfuly';

                if (!data.success) {
                    //$scope.errormessage = 'Could not add computer. Something is wrong. Code: ' + status;
                }
            });
        }

        $scope.$on('$viewContentLoaded', function () {
            $window.ga('send', 'pageview', { 'page': $location.path(), 'title': $scope.$root.title });
        });
    }])


     // Path: /dashboard
    .controller('DashBoardCtrl', ['$scope', '$location', '$window', '$http', function ($scope, $location, $window, $http) {
        $scope.$root.title = 'AssetMan DASH';
        $scope.title = 'AssetMan Dashboard';
        $scope.chart = null;

        $scope.getLastImport = function () {
            $http({
                method: 'GET',
                url: baseUrl + '/api/LastImport',
            }).success(function (data) {
                for (var i = 0; i < data.length; i++) {
                    if (data[i].src == "ad") {
                        $scope.adLastImport = data[i].last_import_time;
                    }
                    if (data[i].src == "sccm") {
                        $scope.sccmLastImport = data[i].last_import_time;
                    }
                    if (data[i].src == "pgp") {
                        $scope.pgpLastImport = data[i].last_import_time;
                    }
                }
            });

        }

        $scope.getActiveMachines = function () {
            $http({ method: 'GET', url: baseUrl + '/api/ActiveMachines' }).
                success(function (data, status, headers, config) {

                    var totalCount = 0;
                    var totalAged = 0;
                    var sccmSource = 0;

                    for (var i = 0; i < data.length; i++) {
                        // Total: Count the total number of active machines.
                        if (data[i]['is_active']) {
                            totalCount++;
                            // Total: Count the total number of active machines.
                            if (data[i]['age_in_days'] > 90) {
                                totalAged++;
                            }
                            if (data[i]['is_src_sccm']) {
                                sccmSource++;
                            }
                        }
                    }
                    $scope.activeMachines = totalCount;
                    $scope.agedComputers = totalAged;
                    $scope.sccmSource = (sccmSource / totalCount) * 100 + '%';
                    buildChart(data);
                }).
                error(function (data, status, headers, config) {
                    $scope.status = "Data not fetched";

                });
        }

        function buildChart(data) {
            //AmCharts.ready(function() {
            //$scope.status = data;
            $scope.chartData = [
            {
                "machine_name": "WIN-7B49JS1RCPI",
                "os": 260
            },
            {
                "machine_name": "naod-pc",
                "age_in_days": 201
            },
            {
                "machine_name": "henok-pc",
                "age_in_days": 65
            }
            ];

            $scope.chart = new AmCharts.AmPieChart();
            // PIE CHART

            // title of the chart
            $scope.chart.addTitle("Machine Distribution", 16);

            $scope.chart.dataProvider = data;
            $scope.chart.titleField = "machine_name";
            $scope.chart.valueField = "machine_id";
            $scope.chart.innerRadius = "30%";
            $scope.chart.startDuration = 0;
            $scope.chart.labelRadius = 15;
            $scope.chart.balloonText = "[[title]]<br><span style='font-size:14px'><b>[[value]]</b> ([[percents]]%)</span>";
            // the following two lines makes the chart 3D
            $scope.chart.depth3D = 10;
            $scope.chart.angle = 15;

            // WRITE                                 
            $scope.chart.write("chartdiv");


            //});
        }


        $scope.$on('$viewContentLoaded', function () {
            $window.ga('send', 'pageview', { 'page': $location.path(), 'title': $scope.$root.title });
        });
    }])


    // Path: /about
    .controller('AboutCtrl', ['$scope', '$location', '$window', function ($scope, $location, $window) {
        $scope.$root.title = 'AngularJS SPA | About';
        $scope.$on('$viewContentLoaded', function () {
            $window.ga('send', 'pageview', { 'page': $location.path(), 'title': $scope.$root.title });
        });
    }])

    // Path: /login
    .controller('LoginCtrl', ['$scope', '$location', '$window', function ($scope, $location, $window) {
        $scope.$root.title = 'AngularJS SPA | Sign In';
        // TODO: Authorize a user
        $scope.login = function () {
            $location.path('/');
            return false;
        };
        $scope.$on('$viewContentLoaded', function () {
            $window.ga('send', 'pageview', { 'page': $location.path(), 'title': $scope.$root.title });
        });
    }])

    // Path: /error/404
    .controller('Error404Ctrl', ['$scope', '$location', '$window', function ($scope, $location, $window) {
        $scope.$root.title = 'Error 404: Page Not Found';
        $scope.$on('$viewContentLoaded', function () {
            $window.ga('send', 'pageview', { 'page': $location.path(), 'title': $scope.$root.title });
        });
    }]);